
c
c geometry correspondence tables common
c *** WARNING ***
c must be preceded by the include file hec_par.inc
c
c original   july 96
c 13/02/97   M. Lefebvre   include the new electronics cabling for
c                          September 1996
c
c 20/03/97   M. Lefebvre   the old hec_pad.inc is now split into
c                          hec_geo.inc  (this file)
c                          hec_ped.inc
c                          hec_cal.inc
c
c 23/11/98   D. O'Neil     include list of bad cells                       
c
c one readout cell (adc channel) can be identified by:
c
c - "adc channel system" 
c    with index ic
c
c - "database system" 
c    with indices i_mod = module number
c                 i_seg = segment (family) number
c                 i_pad = pad number (odd/even scheme)
c
c - "physics system"
c    with indices i_eta = tower eta label
c                 i_phi = tower phi label
c                 i_z   = tower depth number
c
c variables
c
c i_adc_used      actual highest adc channel number used
c i_tim_used      actual number of time slices used
c
c i_mod_used      actual number of modules used
c i_seg_used      actual number of segments used
c i_pad_used      actual number of pads used
c
c i_eta_used      actual number of towers in eta used
c i_phi_used      actual number of tower in phi used
c i_z_used        actual number of tower depths used
c
c tslice_shift    only valid for rus with TDC measurement (after and including
c                 run period Oct 97)
c                 sets the time shift for an event: if the measured TDC value
c                 is greater than tslice_shift, Than TDC=TDC-25.
c                 TDC is a value already in ns.
c                 in all prior run periods this variable doesn't have any 
c                 meaning. (Dieter Striegel)
c
c conv_tdc_time   resolution of TDC constant for each run period
c 
c n_badcells      number of "bad cells" in this run 
c i_badcells_ic   2-d (i,flag) array giving ic, flag for all bad cells
c                 i     = bad cells index (counter)
c                 flag  = 1 value of array is ic number
c                       = 2 value of array is calibration flag
c                           (0=good,1=no calibration,2=bad calibration)
c                       = 3 value or array is digital weights flag
c                           (0=good,1=bad weights)
c
c
c geometry correspondence tables 
c ictodb(ic,3)                  "adc channel system" to "database system"
c ictoph(ic,3)                  "adc channel system" to "physics system"
c i_dbtoic(i_mod,i_seg,i_pad)   "database system" to "adc channel system"
c i_phtoic(i_eta,i_phi,i_z)     "physics system"  to "adc channel system"
c
c
c It is assumed that only 16 pads are connected per segment
c
c note that    1 <= ic <= 256  are high gain  (*4)  gain index = 0
c            257 <= ic <= 512  are low  gain        gain index = 1
c but here only the high gain are considered.
c
c
c MAY 1996 TESTS
c Module present:  Front CDN/USA module
c we have the following ranges of indices:
c
c   ic      i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c  [1,16]     1      1   [1,16]      [1,8]  [1,2]   1
c [17,32]     1      2   [1,16]      [2,9]  [1,2]   2
c [33,48]     1      3   [1,16]     [3,10]  [1,2]   3
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 48 
c
c we therefore have the following values:
c
c i_mod_used = 1       i_eta_used = 10
c i_seg_used = 3       i_phi_used = 2
c i_pad_used = 16      i_z_used   = 3
c
c
c JULY 1996 TESTS
c Modules present:  Front CDN/USA module  (i_mod=1 and i_seg=[1,3])
c                   Front Russia module   (i_mod=2 and i_seg=[1,3])
c                   Back Russia module    (i_mod=1 and i_seg=[4,5])
c note that the back module was positionned in the middle in phi
c note that the CDN/USA module is at high phi
c note that the back module is logically module 1, as for the CDN/USA module
c
c we have the following ranges of indices:
c
c     ic        i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c    [1,16]       1      1   [1,16]      [1,8]  [3,4]   1
c   [17,32]       1      2   [1,16]      [2,9]  [3,4]   2
c   [33,48]       1      3   [1,16]     [3,10]  [3,4]   3
c   [49,64]       1      4   [1,16]     [4,11]  [2,3]   4
c   [65,80]       1      5   [1,16]     [5,12]  [2,3]   5
c   [81,96]       2      1   [1,16]      [1,8]  [1,2]   1
c  [97,112]       2      2   [1,16]      [2,9]  [1,2]   2
c [113,128]       2      3   [1,16]     [3,10]  [1,2]   3
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 128
c
c we therefore have the following values:
c
c i_mod_used = 2       i_eta_used = 12
c i_seg_used = 5       i_phi_used = 4
c i_pad_used = 16      i_z_used   = 5
c
c SEPTEMBER 1996 TESTS
c Modules present:  Front CDN/USA module  (i_mod=1 and i_seg=[1,3])
c                   Front Russia module   (i_mod=2 and i_seg=[1,3])
c                   Back CDN/USA module   (i_mod=1 and i_seg=[4,5])
c                   Back Russia module    (i_mod=2 and i_seg=[4,5])
c note that the CDN/USA module is at high phi
c
c we have the following ranges of indices:
c
c     ic        i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c    [1,16]       1      1   [1,16]      [1,8]  [3,4]   1
c   [17,32]       1      2   [1,16]      [2,9]  [3,4]   2
c   [33,48]       1      3   [1,16]     [3,10]  [3,4]   3
c   [49,64]       1      4   [1,16]     [4,11]  [3,4]   4
c   [65,80]       1      5   [1,16]     [5,12]  [3,4]   5
c   [81,96]       2      1   [1,16]      [1,8]  [1,2]   1
c  [97,112]       2      2   [1,16]      [2,9]  [1,2]   2
c [113,128]       2      3   [1,16]     [3,10]  [1,2]   3
c [129,144]       2      4   [1,16]     [4,11]  [1,2]   4
c [145,160]       2      5   [1,16]     [5,12]  [1,2]   5
c
c IMPORTANT
c note the following cabling of the new electronics which differ
c from the scheme above (zebra refers to the action of the code
c adc96):
c  old    new   zebra
c   ic     ic     ic   i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c   93    173     93     2      1     13          7      1     1
c  107    172    107     2      2     11          7      1     2
c  121    172    107     2      3      9          7      1     2
c  135    169    135     2      4      7          7      1     3
c  149    169    135     2      5      5          7      1     3
c                
c this means that the i_eta=7 tower at i_phi=1 is equipped with the
c new electronics, with depth ganging of segments 2,3 and 4,5.
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 160 with 121 and 149 not used
c
c we have the following values: 
c
c i_mod_used = 2       i_eta_used = 12
c i_seg_used = 5       i_phi_used = 4
c i_pad_used = 16      i_z_used   = 5
c
c
c FEB 1997 TESTS
c Module present:  Front European module
c we have the following ranges of indices:
c
c   ic      i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c  [1,16]     1      1   [1,16]      [1,8]  [1,2]   1
c [17,32]     1      2   [1,16]     [2,10]  [1,2]   2
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 32
c
c we therefore have the following values:
c
c i_mod_used = 1       i_eta_used = 10
c i_seg_used = 2       i_phi_used = 2
c i_pad_used = 16      i_z_used   = 2
c
c MAY 1997 TESTS
c Module present:  Front European module
c we have the following ranges of indices:
c
c   ic      i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c  [1,24]     1      1   [1,24]     [1,12]  [1,2]   1
c [25,48]     1      2   [1,24]     [2,14]  [1,2]   2
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 48 
c
c we therefore have the following values:
c
c i_mod_used = 1       i_eta_used = 14
c i_seg_used = 2       i_phi_used = 2
c i_pad_used = 24      i_z_used   = 2
c
c
c OCTOBER 1997 TESTS  (>>>>>>>>>> GREAT: 1st MODULE 0 <<<<<<<<<)
c author:  06.11.97  Dieter Striegel
c Module present: Front and Back European module
c                 Front and Back Canadian module only as cable dummy
c
c note: in normal datataking the dummy was not read out !
c       for dummy readout -> pads were connected to ADC channels 1..72
c       (not enough ADCs available)
c       ADC table below due to fully equipped modules (hopefully in
c       next run period !)
c
c note: this time philosophy of ADC cabling changed: 
c       groups of ADCs following more like readout towers
c
c we have following ranges of indices:
c
c    ic      i_mod    i_seg     i_pad     i_eta    i_phi   i_z    comment
c  [ 1, 8]     1        1      [ 1, 8]   [1, 4]    [1,2]    1      FRONT
c  [ 9,16]     1        2      [ 1, 8]   [1, 4]    [1,2]    2      FRONT
c  [19,24]     1        3      [ 3, 8]   [2, 4]    [1,2]    3      BACK
c  [25,32]     1        1      [ 9,16]   [5, 8]    [1,2]    1      FRONT
c  [33,40]     1        2      [ 9,16]   [5, 8]    [1,2]    2      FRONT
c  [41,48]     1        3      [ 9,16]   [5, 8]    [1,2]    3      BACK
c  [49,56]     1        1      [17,24]   [9,14]    [1,2]    1      FRONT
c  [57,63]     1        2      [17,23]   [9,13]    [1,2]    2      FRONT
c  [65,72]     1        3      [17,24]   [9,14]    [1,2]    3      BACK
c
c  [73,80]     2        1      [ 1, 8]   [1, 4]    [3,4]    1      dummy
c  [81,88]     2        2      [ 1, 8]   [1, 4]    [3,4]    2      dummy
c  [91,96]     2        3      [ 3, 8]   [2, 4]    [3,4]    3      dummy
c  [97,104]    2        1      [ 9,16]   [5, 8]    [3,4]    1      dummy
c  [105,112]   2        2      [ 9,16]   [5, 8]    [3,4]    2      dummy
c  [113,120]   2        3      [ 9,16]   [5, 8]    [3,4]    3      dummy
c  [121,128]   2        1      [17,24]   [9,14]    [3,4]    1      dummy
c  [129,135]   2        2      [17,23]   [9,13]    [3,4]    2      dummy
c  [137,144]   2        3      [17,24]   [9,14]    [3,4]    3      dummy
c
c note: due to Module 0 Layout: ADC channels 17, 18, 64  missing
c                                            89, 90, 136 missing  (dummy)
c note: pads, which had phi=1.5 due to database were set to phi=1 (or 3 ) 
c       in offline (-> use of integers !)
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <=  72
c 73 <= ic <= 144  dummy module. Only channels 73..128 read out
c
c we therefore have the following values: (dummy excluded !)
c
c i_mod_used = 1       i_eta_used = 14
c i_seg_used = 3       i_phi_used = 2
c i_pad_used = 24      i_z_used   = 3
c
c TDC special:  tslice_shift  = 34.5 
c               conv_tdc_time = 18.1/1000.
c
c CORRESPONDENCE TABLES 
c the following correspondence tables are filled by hec_geo.f
c returned values are 0 if the corresponding channel is not 
c connected or does not exist
c
c from "adc channel system" to "database system"
c ictodb(ic, i_coor) = i_mod if i_coor=1    
c                    = i_seg if i_coor=2 
c                    = i_pad if i_coor=3
c
c from "database system" to "adc channel system"
c dbtoic(i_mod, i_seg, i_pad) = ic 
c
c from "adc channel system" to "physics system" 
c ictoph(ic, i_coor) = i_eta if i_coor=1
c                    = i_phi if i_coor=2
c                    = i_z   if i_coor=3
c
c from "physics system" to "adc channel system"
c phtoic(i_eta, i_phi, i_z)   = ic 
c
c
      integer i_adc_used        !actual highest adc channel number used
      integer i_tim_used        !actual number of time slices used
c
      integer i_mod_used        !actual number of modules used
      integer i_seg_used        !actual number of segments (family) used
      integer i_pad_used        !actual number of pads used
c
      integer i_eta_used        !actual number of towers in eta used
      integer i_phi_used        !actual number of tower in phi used
      integer i_z_used          !actual number of tower depths used
c
      integer ictodb(1:i_adc_dim, 3)
      integer ictoph(1:i_adc_dim, 3)
      integer dbtoic(1:i_mod_max, 1:i_seg_max, 1:i_pad_max)
      integer phtoic(1:i_eta_max, 1:i_phi_max, 1:i_z_max)
c
      integer n_badcells,i_badcells_ic(i_adc_dim,3)
c
      common /sssgeo/ i_adc_used,
     +                i_tim_used,
     +                i_mod_used,
     +                i_seg_used,
     +                i_pad_used,
     +                i_eta_used,
     +                i_phi_used,
     +                i_z_used,
     +                ictodb,
     +                ictoph,
     +                dbtoic,
     +                phtoic,
     +                n_badcells, i_badcells_ic
c















