 1    subroutine hec_his_ini
c
c book online histograms 
c
c this booking routine is called before the pass over events
c it should only be used to book histos that must be filled 
c every event. 
c
      implicit none
c
      include'hec_par.inc'      ! shared parameters
      include'hec_datacard.inc' ! datacard values
      include'hec_geo.inc'      ! geometry correspondance tables
      include'hec_his_sys.inc'  ! histo ids, etc.
      include'hec_runh.inc'     ! run header common
c
c local variables
c
      integer i_z, i, ic
      character*70 ct
      character*1 cd
      character*4 c4
      integer nbin
      integer id
c
c zero our moments arrays
c
      call vzero(adcmom,i_adc_dim*i_tim_dim*3)
      call vzero(maxmom,i_adc_dim*3)
c
      print *, ' *** booking event by event histograms'
c
c histo type 4 -- tdc correction
c
      print *, ' *** histo_switch is ',histo_switch
      if (histo_switch(4) .eq. 1) then
c
c tdc distribution 
c
        nbin = 100
        write(c4, '(i4)') ic
        ct = 'tdc distribution (ns) '//c4
        id = id_tdc 
        call hbook1(id, ct, nbin, 0., 100., 0.)
      endif
c
c histo type 2 -- geometrical energy distribution
c
      if (histo_switch(2) .eq. 1) then
c
c adc(max)-ped distribution for each depth
c
        nbin = 100
        do i_z = 1, i_z_used
          write(cd, '(i1)') i_z
          ct = 'adc(max) - ped for tower depth '//cd
          id = id_adc_z + i_z
          call hbook1(id, ct, nbin, 1., -1., 0.)
        enddo
      endif
c
c book histograms for each channel
c
      do ic = 1, i_adc_used
c
c histo type 3 -- no calibration, no tdc correction
c
        if (histo_switch(3) .eq. 1) then
c
c adc(max)-ped distribution for each channel
c
          nbin = 100
          write(c4, '(i4)') ic
          ct = 'adc(max) - ped for channel '//c4
          id = id_adc_ic + ic
          call hbook1(id, ct, nbin, 0., 2000., 0.)
c
c time(max) distribution in ns for each channel for 1997 or later
c
          if (irunpd .ge. 4) then
            nbin = 100
            write(c4, '(i4)') ic
            ct = 'time(max) for channel '//c4//' (ns)'
            id = id_tim_ic + ic
            call hbook1(id, ct, nbin, -5. , 5. , 0.)
          endif
c
        endif
c
c histo type 4 -- tdc corrected
c
        if (histo_switch(4) .eq. 1) then
c
c time(max) distribution in ns (TDC corrected) for each channel 
c for 1997 or later for cubic fit only
c
          if (irunpd .ge. 4 .and. m_pref .eq. 1) then
            nbin = 500
            write(c4, '(i4)') ic
            ct = 'time(max)+TDC for channel '//c4//' (ns) (cubic fit)'
            id = id_tim_icns + ic
            call hbook1(id, ct, nbin, 0.5 , nbin+0.5 , 0.)
          endif
        endif
c
c histo type 5 -- Calibration correction
c
        if (histo_switch(5) .eq. 1) then
c
c calibrated energy for each channel, if calibration is turned on
c
          nbin = 100
          if (io_cal(1) .gt. 0) then
            write(c4, '(i4)') ic
            ct = 'energy in nA for channel '//c4
            id = id_cal_ic + ic
            call hbook1(id, ct, nbin, 1., -1., 0.)  
          endif
c
        endif
c
      enddo
c
c histo type 5 -- Calibration correction
c
      if (histo_switch(5) .eq. 1) then
c
c calibrated energy if above sigma cut
c
        ct = 'energy in nA for channels above 1 sigma '
        id = id_sigma + 1
        call hbook1(id, ct, nbin, 0., 400.*e_beam, 0.)  
        ct = 'energy in nA for channels above 2 sigma '
        id = id_sigma + 2
        call hbook1(id, ct, nbin, 0., 400.*e_beam, 0.)  
        ct = 'energy in nA for channels above 3 sigma '
        id = id_sigma + 3
        call hbook1(id, ct, nbin, 0., 400.*e_beam, 0.)
      endif  
c
c
c histo type 6 -- Clustered Energy
c
      if (histo_switch(6) .eq. 1) then
c
c Convert Hollerith integer back into characters for clustering titles
c
c fill the array his_clus_index that contains the cluster numbers for the
c clusters that are used (poll on the number of cells)
c fill his_clus_num, the total number of filled entries in his_clus_index
c
        call vzero(his_clus_index,nclust_dim)
        his_clus_num = 0
        do i = 1, nclust_dim
          if (his_clus_cell_array(1, i) .gt. 0) then
            his_clus_num = his_clus_num + 1
            his_clus_index(his_clus_num) = i
          endif
        enddo
c
        do i = 1, his_clus_num
          call UHTOC (his_clus_ititle(his_clus_index(i)),4,
     +                his_clus_title(his_clus_index(i)),4)
        enddo
c
c set depth weights for cluster
c
        depthw(1) = 1.
        depthw(2) = 1.
        depthw(3) = 2.
        do i=1, his_clus_num
          write (ct,8) his_clus_title(his_clus_index(i))
 8        format ('Energy Cluster: ',A4)
          id = i + id_clus
          call hbook1(id, ct, 100, 0., 15.*e_beam, 0.)
        enddo
      endif
      print *, ' *** end of event histogram booking'
c
      return
      end

































































